@@ -102,7 +102,9 @@ class Battle : public IBattle
 
     void OnTimer( wxTimerEvent& /*event*/ );
 
-		void SetInGame( bool ingame );
+	void SetInGame( bool ingame );
+
+	void OnUnitsyncReloaded( GlobalEvents::GlobalEventData data );
 
   protected:
     // Battle variables
@@ -125,9 +127,9 @@ class Battle : public IBattle
 
 /**
     This file is part of SpringLobby,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
