@@ -147,14 +147,13 @@ BattleRoomTab::BattleRoomTab( wxWindow* parent, Battle* battle )
 	m_color_lbl = new wxStaticText( m_player_panel, -1, _( "Color" ) );
 	m_side_lbl = new wxStaticText( m_player_panel, -1, _( "Side" ) );
 
-	m_player_count_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Players: %d" ), 0 ) );
-	m_spec_count_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Spectators: %d" ), 0 ) );
 	m_ally_setup_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Setup: %s" ), _T("") ) );
-	m_ok_count_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Unready/Unsynced: %d" ), 0 ) );
+	m_ok_count_lbl = new wxStaticText( m_player_panel, -1, wxString::Format( _( "Unready: %d" ), 0 ) );
 
-	m_size_lbl = new wxStaticText( this, -1, _T( "" ) );
-	m_wind_lbl = new wxStaticText( this, -1, _T( "" ) );
-	m_tidal_lbl = new wxStaticText( this, -1, _T( "" ) );
+	//XXX not needed ?
+//	m_size_lbl = new wxStaticText( this, -1, _T( "" ) );
+//	m_wind_lbl = new wxStaticText( this, -1, _T( "" ) );
+//	m_tidal_lbl = new wxStaticText( this, -1, _T( "" ) );
 
 	m_map_combo = new wxComboBox( this, BROOM_MAP_SEL, _T( "" ), wxDefaultPosition, wxDefaultSize );
 
@@ -261,7 +260,7 @@ BattleRoomTab::BattleRoomTab( wxWindow* parent, Battle* battle )
 	m_preset_btns_sizer->Add( m_delete_btn, 0, wxEXPAND );
 
 	m_default_btn = new wxButton( this, BROOM_SETDEFAULTPRES, _( "Set default" ), wxDefaultPosition, wxDefaultSize );
-	m_default_btn->SetToolTip( TE( _( "Use the current set of options as mod's default." ) ) );
+	m_default_btn->SetToolTip( TE( _( "Use the current set of options as game's default." ) ) );
 
 	m_preset_btns_sizer->Add( m_default_btn, 0, wxEXPAND );
 
@@ -309,8 +308,6 @@ BattleRoomTab::BattleRoomTab( wxWindow* parent, Battle* battle )
 	m_player_sett_sizer->Add( m_ready_chk, 0, wxEXPAND | wxALL, 2 );
 	m_player_sett_sizer->AddStretchSpacer();
 	m_player_sett_sizer->Add( m_ally_setup_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT | wxALL, 2 );
-	m_player_sett_sizer->Add( m_player_count_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT  | wxALL, 2 );
-	m_player_sett_sizer->Add( m_spec_count_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT | wxALL, 2 );
 	m_player_sett_sizer->Add( m_ok_count_lbl, 0, wxALIGN_CENTER_VERTICAL | wxALIGN_RIGHT | wxALL, 2 );
 
 	m_players_sizer->Add( m_players, 1, wxEXPAND );
@@ -419,6 +416,7 @@ void BattleRoomTab::UpdateBattleInfo()
 	if ( !m_battle ) return;
 	m_lock_chk->SetValue( m_battle->IsLocked() );
 	m_minimap->UpdateMinimap();
+	UpdateMapInfoSummary();
 }
 
 void BattleRoomTab::PrintAllySetup()
@@ -426,12 +424,27 @@ void BattleRoomTab::PrintAllySetup()
 	wxString setupstring;
 	if ( m_battle )
 	{
+		setupstring += _T("<") + TowxString( m_battle->GetSpectators() ) + _T("> ");
+		setupstring += _T(" [") + TowxString( m_battle->GetNumActivePlayers() ) + _T("]: ");
+		wxString alliancesstring;
+		int previousalliancesize = 0;
+		bool ffamode = true;
 		std::map<int, int> allysizes = m_battle->GetAllySizes();
-		for ( std::map<int, int>::iterator itor = allysizes.begin(); itor != allysizes.end(); itor++ )
+		if ( allysizes.size() < 3 ) ffamode = false;
+		for ( std::map<int, int>::const_iterator itor = allysizes.begin(); itor != allysizes.end(); ++itor )
 		{
-			if ( itor != allysizes.begin() ) setupstring += _T("v");
-			setupstring += TowxString( itor->second );
+			if ( itor != allysizes.begin() )
+			{
+				alliancesstring += _T("v");
+				if (previousalliancesize != itor->second) ffamode = false;
+			}
+			else previousalliancesize = itor->second;
+			alliancesstring += TowxString( itor->second );
+			//this takes space needlessy
+			//alliancesstring += wxString::Format( _T("(%d)") , itor->first );
 		}
+		if ( !ffamode ) setupstring += alliancesstring;
+		else setupstring += wxString::Format(_("%d way FFA"), previousalliancesize);
 	}
 	m_ally_setup_lbl->SetLabel( wxString::Format( _( "Setup: %s" ), setupstring.c_str() ) );
 	Layout();
@@ -461,25 +474,12 @@ void BattleRoomTab::UpdateBattleInfo( const wxString& Tag )
 		}
 		m_opts_list->SetItem( index, 1, value );
 	}
-	else if ( type == OptionsWrapper::PrivateOptions )
+	else// if ( type == OptionsWrapper::PrivateOptions )
 	{
 		if ( key == _T( "mapname" ) ) // the map has been changed
 		{
-			try   // updates map info summary
-			{
-				ASSERT_EXCEPTION( m_battle->MapExists(), _( "Map does not exist." ) );
-				UnitSyncMap map = m_battle->LoadMap();
-				m_opts_list->SetItem( m_opt_list_map[ _( "Size" ) ] , 1, wxString::Format( _T( "%.0fx%.0f" ), map.info.width / 512.0, map.info.height / 512.0 ) );
-				m_opts_list->SetItem( m_opt_list_map[ _( "Windspeed" ) ], 1, wxString::Format( _T( "%d-%d" ), map.info.minWind, map.info.maxWind ) );
-				m_opts_list->SetItem( m_opt_list_map[ _( "Tidal strength" ) ], 1, wxString::Format( _T( "%d" ), map.info.tidalStrength ) );
-				//    m_opts_list->SetItem( 0, 1,  );
-			}
-			catch ( ... )
-			{
-				m_opts_list->SetItem( m_opt_list_map[ _( "Size" ) ], 1, _T( "?x?" ) );
-				m_opts_list->SetItem( m_opt_list_map[ _( "Windspeed" ) ], 1, _T( "?-?" ) );
-				m_opts_list->SetItem( m_opt_list_map[ _( "Tidal strength" ) ], 1, _T( "?" ) );
-			}
+		    UpdateMapInfoSummary();
+
 			wxString mapname =m_battle->GetHostMapName();
 			int index_ = m_map_combo->FindString( mapname );
 			if ( index_ != wxNOT_FOUND )
@@ -510,14 +510,33 @@ BattleroomListCtrl& BattleRoomTab::GetPlayersListCtrl()
 	return *m_players;
 }
 
+void BattleRoomTab::UpdateMapInfoSummary() {
+    try {
+        ASSERT_EXCEPTION( m_battle->MapExists(), _( "Map does not exist." ) );
+        UnitSyncMap map = m_battle->LoadMap();
+        m_opts_list->SetItem( m_opt_list_map[ _( "Size" ) ] , 1, wxString::Format( _T( "%.0fx%.0f" ), map.info.width / 512.0, map.info.height / 512.0 ) );
+        m_opts_list->SetItem( m_opt_list_map[ _( "Windspeed" ) ], 1, wxString::Format( _T( "%d-%d" ), map.info.minWind, map.info.maxWind ) );
+        m_opts_list->SetItem( m_opt_list_map[ _( "Tidal strength" ) ], 1, wxString::Format( _T( "%d" ), map.info.tidalStrength ) );
+        //    m_opts_list->SetItem( 0, 1,  );
+    } catch ( ... ) {
+        m_opts_list->SetItem( m_opt_list_map[ _( "Size" ) ], 1, _T( "?x?" ) );
+        m_opts_list->SetItem( m_opt_list_map[ _( "Windspeed" ) ], 1, _T( "?-?" ) );
+        m_opts_list->SetItem( m_opt_list_map[ _( "Tidal strength" ) ], 1, _T( "?" ) );
+    }
+}
+
 void BattleRoomTab::UpdateStatsLabels()
 {
-	m_player_count_lbl->SetLabel( wxString::Format( _( "Players: %d" ), m_battle->GetNumActivePlayers() ) );
-	m_spec_count_lbl->SetLabel( wxString::Format( _( "Spectators: %d" ), m_battle->GetSpectators() ) );
-	m_ok_count_lbl->SetLabel( wxString::Format( _( "Unready/Unsynced: %d" ), m_battle->GetNumActivePlayers() - m_battle->GetNumOkPlayers() ) );
+	m_ok_count_lbl->SetLabel( wxString::Format( _( "Unready: %d" ), m_battle->GetNumActivePlayers() - m_battle->GetNumOkPlayers() ) );
 	PrintAllySetup();
 }
 
+void BattleRoomTab::UpdateMyInfo() {
+    if ( !m_battle ) return;
+    m_players->UpdateUser(m_battle->GetMe());
+    m_players->RefreshVisibleItems();
+}
+
 void BattleRoomTab::UpdateUser( User& user )
 {
 	if ( !m_battle ) return;
@@ -552,7 +571,7 @@ void BattleRoomTab::UpdateUser( User& user )
 		m_ready_chk->Enable();
 	}
 
-	icons().SetColourIcon( bs.team, user.BattleStatus().colour );
+	icons().SetColourIcon( user.BattleStatus().colour );
 	m_color_sel->SetColor( user.BattleStatus().colour );
 }
 
@@ -782,6 +801,7 @@ void BattleRoomTab::OnSideSel( wxCommandEvent& /*unused*/ )
 {
 	if ( !m_battle ) return;
 	m_battle->ForceSide( m_battle->GetMe(), m_side_sel->GetSelection() );
+	sett().SetBattleLastSideSel( m_battle->GetHostModName(), m_side_sel->GetSelection() );
 }
 
 
@@ -894,7 +914,7 @@ long BattleRoomTab::AddMMOptionsToList( long pos, OptionsWrapper::GameOption opt
 {
 	if ( !m_battle ) return -1;
 	OptionsWrapper::wxStringTripleVec optlist = m_battle->CustomBattleOptions().getOptions( optFlag );
-	for ( OptionsWrapper::wxStringTripleVec::iterator it = optlist.begin(); it != optlist.end(); it++ )
+	for ( OptionsWrapper::wxStringTripleVec::const_iterator it = optlist.begin(); it != optlist.end(); ++it )
 	{
 		m_opts_list->InsertItem( pos, it->second.first );
 		wxString tag = wxString::Format( _T( "%d_" ), optFlag ) + it->first;
@@ -949,7 +969,7 @@ void BattleRoomTab::OnSetModDefaultPreset( wxCommandEvent& /*unused*/ )
 {
 	if ( !m_battle ) return;
 	wxArrayString choices = m_battle->GetPresetList();
-	int result = wxGetSingleChoiceIndex( _( "Pick an existing option set from the list" ), _( "Set mod default preset" ), choices );
+	int result = wxGetSingleChoiceIndex( _( "Pick an existing option set from the list" ), _( "Set game default preset" ), choices );
 	if ( result < 0 ) return;
 	sett().SetModDefaultPresetName( m_battle->GetHostModName(), choices[result] );
 }
@@ -1023,7 +1043,7 @@ void BattleRoomTab::OnOptionActivate( wxListEvent& event )
 	long index = event.GetIndex();
 	if ( index == 0 ) return;
 	wxString tag;
-	for ( OptionListMap::iterator itor = m_opt_list_map.begin(); itor != m_opt_list_map.end(); itor++ )
+	for ( OptionListMap::const_iterator itor = m_opt_list_map.begin(); itor != m_opt_list_map.end(); ++itor )
 	{
 		if ( itor->second == index )
 		{
@@ -1170,7 +1190,7 @@ void BattleRoomTab::OnBattleActionEvent( UiEvents::UiEventData data )
 	GetChatPanel().DidAction( nick, msg );
 }
 
-void BattleRoomTab::OnHostNew( wxCommandEvent& event )
+void BattleRoomTab::OnHostNew( wxCommandEvent& /*event*/ )
 {
 	if ( !ui().IsConnected() )
 	{
@@ -1197,3 +1217,4 @@ void BattleRoomTab::OnHostNew( wxCommandEvent& event )
 //	Layout();
 //	Refresh();
 //}
+
