@@ -16,6 +16,7 @@
 #include "settings.h"
 #include "utils/conversion.h"
 #include "ui.h"
+#include "defines.h"
 
 #include "utils/customdialogs.h"
 #include "utils/platform.h"
@@ -251,9 +252,14 @@ find_tail_sequences(int fd, const char* bytes, size_t bytes_length, size_t count
 			if (  strncmp(source, "##", 2) != 0 ) {
 			    out.Insert(wxString(L'\0', 0), 0);
 			    wxLogMessage(_T("ChatLog::find_tail_sequences: fetching write buffer for %lu bytes"), sizeof(wxChar) * (line_length + 1));
-
-			    wxConvUTF8.MB2WC(out[0].GetWriteBuf(sizeof(wxChar) * (line_length + 1)), source, line_length);
-			    out[0].UngetWriteBuf(line_length);
+			    #ifndef HAVE_WX28
+			    	wxStringBufferLength outzero_buf(out[0], sizeof(wxChar) * (line_length + 1));
+			    	wxConvUTF8.ToWChar(outzero_buf, line_length, source);
+			    	outzero_buf.SetLength(line_length);
+			    #else
+			    	wxConvUTF8.MB2WC(out[0].GetWriteBuf(sizeof(wxChar) * (line_length + 1)), source, line_length);
+			    	out[0].UngetWriteBuf(line_length);
+			    #endif
 
 			    ++count_added;
 			}
@@ -308,3 +314,4 @@ void ChatLog::FillLastLineArray()
     delete[] eol;
 #endif
 }
+
