@@ -128,8 +128,6 @@ MainWindow::MainWindow( )
 	m_log_win(NULL),
 	m_has_focus(true)
 {
-	assert( !wxGetApp().IsSimple() );
-	//! \todo use customised icon
 	SetIcon( SLcustomizations().GetAppIcon() );
 
 	GetAui().manager = new AuiManagerContainer::ManagerType( this );
@@ -168,7 +166,7 @@ MainWindow::MainWindow( )
 	m_menuTools->Append(MENU_RENAME, _("Change &username"));
 	m_menuTools->Append(MENU_SCREENSHOTS, _("&View screenshots"));
 	m_menuTools->AppendSeparator();
-	m_menuTools->Append(MENU_USYNC, _("&Reload maps/mods"));
+	m_menuTools->Append(MENU_USYNC, _("&Reload maps/games"));
 
 
 #ifndef NO_TORRENT_SYSTEM
@@ -245,7 +243,7 @@ MainWindow::MainWindow( )
 	UpdateMainAppHasFocus(m_has_focus);
 }
 
-wxBitmap MainWindow::GetTabIcon( const unsigned char* data, size_t size )
+wxBitmap MainWindow::GetTabIcon( const unsigned char* data, size_t size ) const
 {
     if ( sett().GetUseTabIcons() )
         return charArr2wxBitmap( data , size );
@@ -346,7 +344,7 @@ void MainWindow::OnKillFocus(wxFocusEvent&)
 	UpdateMainAppHasFocus(m_has_focus);
 }
 
-bool MainWindow::HasFocus()
+bool MainWindow::HasFocus() const
 {
 	return m_has_focus;
 }
@@ -427,6 +425,7 @@ ChatPanel* MainWindow::GetActiveChatPanel()
 {
   unsigned int index = m_func_tabs->GetSelection();
   if ( index == PAGE_CHAT ) return m_chat_tab->GetActiveChatPanel();
+  //! TODO (koshi) this doesn't work when in broom an and sending "/help (ShowMessage() )
   if ( index == PAGE_JOIN ) return m_join_tab->GetActiveChatPanel();
   return 0;
 }
@@ -447,7 +446,7 @@ void MainWindow::OpenChannelChat( Channel& channel, bool doFocus )
     ASSERT_LOGIC( m_chat_tab != 0, _T("m_chat_tab") );
     if ( doFocus )
         m_func_tabs->SetSelection( PAGE_CHAT );
-    m_chat_tab->AddChatPanel( channel );
+	m_chat_tab->AddChatPanel( channel, doFocus );
 }
 
 
@@ -493,7 +492,7 @@ void MainWindow::ShowChannelChooser()
         return;
 
     if ( !ui().IsConnected() )
-        customMessageBox( SL_MAIN_ICON, _("You need to be connected to server to view channel list"), _("Not connected") );
+        customMessageBox( SL_MAIN_ICON, _("You need to be connected to a server to view the channel list"), _("Not connected") );
     else {
         m_channel_chooser->ClearChannels();
 		serverSelector().GetServer().RequestChannels();
@@ -664,7 +663,7 @@ void MainWindow::OnChannelListStart( )
     m_channel_chooser->ClearChannels();
 }
 
-wxString MainWindow::AddPerspectivePostfix( const wxString& pers_name )
+wxString MainWindow::AddPerspectivePostfix( const wxString& pers_name ) const
 {
     wxString perspective_name  = pers_name.IsEmpty() ? sett().GetLastPerspectiveName() : pers_name;
     if ( m_join_tab &&  m_join_tab->UseBattlePerspective() )
@@ -689,7 +688,7 @@ void MainWindow::OnMenuSaveLayout( wxCommandEvent& /*unused*/ )
 void MainWindow::OnMenuLoadLayout( wxCommandEvent& /*unused*/ )
 {
 	wxArrayString layouts = sett().GetPerspectives();
-	unsigned int result = wxGetSingleChoiceIndex( _("Which profile fo you want to load?"), _("Layout manager"), layouts );
+	unsigned int result = wxGetSingleChoiceIndex( _("Which profile do you want to load?"), _("Layout manager"), layouts );
 	if ( result > layouts.GetCount() )
         return;
 
