@@ -1,8 +1,8 @@
 /**
     This file is part of springsettings,
-    Copyright (C) 2007-09
+    Copyright (C) 2007-2010
 
-    springsettings is free software: you can redistribute it and/or modify
+    SpringLobby is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2 as published by
     the Free Software Foundation.
 
@@ -59,6 +59,7 @@ class tab_quality_video : public abstract_panel
 		void CreateGUIControls();
 
 		wxComboBox* ctrl_waterQ_CBox;
+		wxComboBox* ctrl_shadows_CBox;
 		wxCheckBox** ctrl_vo_Boxes;
 		static const int ctrl_vo_Boxes_size = 3;
 		wxTextCtrl* ctrl_x_res;
