@@ -9,6 +9,7 @@
 	#include <wx/msw/registry.h>
 #endif
 #include "Helper/slconfig.h"
+#include "defines.h" //to get HAVEWX??
 
 #include <wx/filename.h>
 #include <wx/filefn.h>
@@ -22,6 +23,9 @@
 #include <wx/wfstream.h>
 #include <wx/settings.h>
 #include <wx/tokenzr.h>
+#ifdef HAVE_WX29
+	#include <wx/colourdata.h>
+#endif
 
 #include "nonportable.h"
 #include "utils/conversion.h"
@@ -57,19 +61,27 @@ Settings& sett()
 Settings::Settings()
 {
 #if defined(__WXMSW__) || defined(__WXMAC__)
-	wxString userfilepath = IdentityString( wxStandardPaths::Get().GetUserDataDir() + wxFileName::GetPathSeparator() + _T( "%s.conf" ), true );
+	wxString userfilepath = IdentityString( GetConfigfileDir() + wxFileName::GetPathSeparator() + _T( "%s.conf" ), true );
 	wxString localfilepath =  IdentityString( GetExecutableFolder() + wxFileName::GetPathSeparator() + _T( "%s.conf" ), true );
 
-	if ( !wxFileName::FileExists( localfilepath ) || !wxFileName::IsFileWritable( localfilepath ) )
+	if ( m_user_defined_config && wxFileName::IsFileWritable( m_user_defined_config_path ) )
 	{
-	    //either local conf file soes not exist, or it exists but is not writable
-		m_chosen_path = userfilepath;
+		m_chosen_path = m_user_defined_config_path;
 		SetPortableMode( false );
 	}
 	else
 	{
-		m_chosen_path = localfilepath; // portable mode, use only current app paths
-		SetPortableMode ( true );
+		if ( !wxFileName::FileExists( localfilepath ) || !wxFileName::IsFileWritable( localfilepath ) )
+		{
+			//either local conf file soes not exist, or it exists but is not writable
+			m_chosen_path = userfilepath;
+			SetPortableMode( false );
+		}
+		else
+		{
+			m_chosen_path = localfilepath; // portable mode, use only current app paths
+			SetPortableMode ( true );
+		}
 	}
 
 	// if it doesn't exist, try to create it
@@ -101,7 +113,7 @@ Settings::Settings()
 	}
 	m_config = new slConfig( instream );
 #else
-	wxString localpath = wxString::Format( _T( ".%s/%s.conf" ), GetAppName( true ).c_str(), GetAppName( true ).c_str() );
+	wxString localpath = wxString::Format( _T( "%s/%s.conf" ), GetConfigfileDir().c_str(), GetAppName( true ).c_str() );
 	wxString path = m_user_defined_config ? m_user_defined_config_path : localpath;
 	m_config = new slConfig( GetAppName(), wxEmptyString, path );
 	SetPortableMode ( false );
@@ -1130,7 +1142,7 @@ void Settings::SetLastHostRelayedMode( bool value )
 void Settings::SetHostingPreset( const wxString& name, int optiontype, std::map<wxString, wxString> options )
 {
 	m_config->DeleteGroup( _T( "/Hosting/Preset/" ) + name + _T( "/" ) + TowxString( optiontype ) );
-	for ( std::map<wxString, wxString>::iterator it = options.begin(); it != options.end(); ++it )
+	for ( std::map<wxString, wxString>::const_iterator it = options.begin(); it != options.end(); ++it )
 	{
 		m_config->Write( _T( "/Hosting/Preset/" ) + name + _T( "/" ) + TowxString( optiontype ) + _T( "/" ) + it->first , it->second );
 	}
@@ -1646,6 +1658,16 @@ void Settings::SetBattleLastAutoAnnounceDescription( bool value )
 	m_config->Write( _T( "/Hosting/AutoAnnounceDescription" ) , value );
 }
 
+void Settings::SetBattleLastSideSel( const wxString& modname, int sidenum )
+{
+	m_config->Write(_T("/Battle/Sides/" + modname), sidenum);
+}
+
+int Settings::GetBattleLastSideSel( const wxString& modname )
+{
+	return m_config->Read( _T("/Battle/Sides/" + modname), 0l );
+}
+
 void Settings::SetMapLastStartPosType( const wxString& mapname, const wxString& startpostype )
 {
 	m_config->Write( _T( "/Hosting/MapLastValues/" ) + mapname + _T( "/startpostype" ), startpostype );
@@ -1655,7 +1677,7 @@ void Settings::SetMapLastRectPreset( const wxString& mapname, std::vector<Settin
 {
 	wxString basepath = _T( "/Hosting/MapLastValues/" ) + mapname + _T( "/Rects" );
 	m_config->DeleteGroup( basepath );
-	for ( std::vector<Settings::SettStartBox>::iterator itor = rects.begin(); itor != rects.end(); itor++ )
+	for ( std::vector<Settings::SettStartBox>::const_iterator itor = rects.begin(); itor != rects.end(); ++itor )
 	{
 		SettStartBox box = *itor;
 		wxString additionalpath = basepath + _T( "/Rect" ) + TowxString( box.ally ) + _T( "/" );
@@ -2494,7 +2516,6 @@ void Settings::SetDoResetPerspectives( bool do_it )
 	m_config->Write(_T( "/reset_perspectives" ) , (long)do_it );
 }
 
-
 bool Settings::GetBroadcastEverywhere()
 {
 	return m_config->Read( _T("/Chat/BroadcastEverywhere") ,true);
@@ -2506,20 +2527,55 @@ void Settings::SetBroadcastEverywhere(bool value)
 }
 
 //Hotkeys stuff (for springsettings)
-void Settings::SetHotkey( const wxString& profileName, const wxString& command, const wxString& key, bool unbind )
+void Settings::SetHotkeyMeta( const wxString& profileName, const wxString& keyStr )
 {
-	wxString bindStr = wxT("bind");
-	if ( unbind )
-	{
-		bindStr = wxT("unbind");
-	}
-
-	m_config->Write(_T( "/HotkeyProfiles/") + profileName + _T("/") + command + _T("/") + key, bindStr );
+	m_config->Write(_T( "/HotkeyProfiles/") + profileName + _T("/Meta"), keyStr);
 }
 
-wxString Settings::GetHotkey( const wxString& profileName, const wxString& command, const wxString& key )
+wxString Settings::GetHotkeyMeta( const wxString& profileName )
 {
-	return m_config->Read( _T( "/HotkeyProfiles/") + profileName + _T("/") + command + _T("/") + key, _T("") );
+	return m_config->Read(_T( "/HotkeyProfiles/") + profileName + _T("/Meta"), _T("") );
+}
+
+void Settings::SetHotkeyKeySymSet( const wxString& profileName, const wxString& setName, const wxString& keyStr )
+{
+	m_config->Write(_T( "/HotkeyProfiles/") + profileName + _T("/KeySets/") + setName, keyStr);
+}
+
+wxString Settings::GetHotkeyKeySymSet( const wxString& profileName, const wxString& setName )
+{
+	return m_config->Read( _T( "/HotkeyProfiles/") + profileName + _T("/KeySets/") + setName, _T("") );
+}
+
+wxArrayString Settings::GetHotkeyKeySymSetNames( const wxString& profileName )
+{
+	return GetEntryList( _T( "/HotkeyProfiles/" ) + profileName + _T("/KeySets/") );
+}
+
+void Settings::SetHotkeyKeySym( const wxString& profileName, const wxString& symName, const wxString& keyStr )
+{
+	m_config->Write(_T( "/HotkeyProfiles/") + profileName + _T("/KeySyms/") + symName, keyStr);
+}
+
+wxString Settings::GetHotkeyKeySym( const wxString& profileName, const wxString& symName )
+{
+	return m_config->Read( _T( "/HotkeyProfiles/") + profileName + _T("/KeySyms/") + symName, _T("") );
+}
+
+wxArrayString Settings::GetHotkeyKeySymNames( const wxString& profileName )
+{
+	return GetEntryList( _T( "/HotkeyProfiles/" ) + profileName + _T("/KeySyms/") );
+}
+
+// oderidx == -1 means unbind
+void Settings::SetHotkey( const wxString& profileName, const wxString& command, const wxString& key, int orderIdx )
+{
+	m_config->Write(_T( "/HotkeyProfiles/") + profileName + _T("/Bindings/") + wxString::Format(wxT("%i"),orderIdx) + _T("/") + key, command );
+}
+
+wxString Settings::GetHotkey( const wxString& profileName, const wxString& orderIdx, const wxString& key )
+{
+	return m_config->Read( _T( "/HotkeyProfiles/") + profileName + _T("/Bindings/") + orderIdx + _T("/") + key, _T("") );
 }
 
 wxArrayString Settings::GetHotkeyProfiles()
@@ -2527,14 +2583,14 @@ wxArrayString Settings::GetHotkeyProfiles()
 	return GetGroupList( _T( "/HotkeyProfiles/" ) );
 }
 
-wxArrayString Settings::GetHotkeyProfileCommands( const wxString& profileName )
+wxArrayString Settings::GetHotkeyProfileOrderIndices( const wxString& profileName )
 {
-	return GetGroupList( _T( "/HotkeyProfiles/" ) + profileName + _T("/") );
+	return GetGroupList( _T( "/HotkeyProfiles/" ) + profileName + _T("/Bindings/") );
 }
 
-wxArrayString Settings::GetHotkeyProfileCommandKeys( const wxString& profileName, const wxString& command )
+wxArrayString Settings::GetHotkeyProfileCommandKeys( const wxString& profileName, const wxString& orderIdx )
 {
-	return GetEntryList( _T( "/HotkeyProfiles/" ) + profileName + _T("/") + command + _T("/") );
+	return GetEntryList( _T( "/HotkeyProfiles/" ) + profileName + _T("/Bindings/") + orderIdx + _T("/") );
 }
 
 void Settings::DeleteHotkeyProfiles()
@@ -2549,3 +2605,8 @@ wxString Settings::GetUikeys( const wxString& index )
 }
 
 //END OF Hotkeys stuff (for springsettings)
+
+bool Settings::IgnoreOfferfile()
+{
+	return m_config->Read( _T("/IgnoreOfferfile"), 0l);
+}
