@@ -46,7 +46,7 @@ BEGIN_EVENT_TABLE( Spring, wxEvtHandler )
 
     EVT_COMMAND ( PROC_SPRING, wxEVT_SPRING_EXIT, Spring::OnTerminated )
 
-END_EVENT_TABLE();
+END_EVENT_TABLE()
 
 #define FIRST_UDP_SOURCEPORT 8300
 
@@ -395,7 +395,7 @@ wxString Spring::WriteScriptTxt( IBattle& battle ) const
 			tdf.Append( _T("NumRestrictions"), units.size());
 			tdf.EnterSection( _T("RESTRICT") );
 				int restrictcount = 0;
-				for ( std::map<wxString, int>::iterator itor = units.begin(); itor != units.end(); itor++ )
+				for ( std::map<wxString, int>::const_iterator itor = units.begin(); itor != units.end(); itor++ )
 				{
 						tdf.Append(_T("Unit") + TowxString( restrictcount ), itor->first );
 						tdf.Append(_T("Limit") + TowxString( restrictcount ), itor->second );
