@@ -58,8 +58,6 @@
 #include "alsound.h"
 #include "mapselectdialog.h"
 
-#include "gui/simplefront.h"
-
 #include <wx/debugrpt.h>
 #include "utils/misc.h"
 
@@ -84,7 +82,6 @@ SpringLobbyApp::SpringLobbyApp()
 	m_log_file( false ),
     m_log_window_show( false ),
     m_crash_handle_disable( false ),
-	m_start_simple_interface( false ),
 	m_appname( _T("SpringLobby") )
 {
 }
@@ -110,6 +107,7 @@ LONG __stdcall filter(EXCEPTION_POINTERS* p){
 //! It will open the main window and connect default to server or open the connect window.
 bool SpringLobbyApp::OnInit()
 {
+	wxSetEnv( _T("UBUNTU_MENUPROXY"), _T("0") );
     //this triggers the Cli Parser amongst other stuff
     if (!wxApp::OnInit())
 		return false;
@@ -150,8 +148,8 @@ bool SpringLobbyApp::OnInit()
     m_translationhelper = new wxTranslationHelper( *( (wxApp*)this ), path );
     m_translationhelper->Load();
 
-    if ( !wxDirExists( wxStandardPaths::Get().GetUserDataDir() ) )
-        wxMkdir( wxStandardPaths::Get().GetUserDataDir() );
+	if ( !wxDirExists( GetConfigfileDir() ) )
+		wxMkdir( GetConfigfileDir() );
 
 #ifdef __WXMSW__
 	sett().SetSearchSpringOnlyInSLPath( sett().GetSearchSpringOnlyInSLPath() );
@@ -169,10 +167,8 @@ bool SpringLobbyApp::OnInit()
 
 	sett().RefreshSpringVersionList();
 
-	//!currently we cannot use the dialog in simple, because it uses Ui and therefore creates mainwindow
-	if ( !m_start_simple_interface )
-		//this should take off the firstload time considerably *ie nil it :P )
-		mapSelectDialog();
+	//this should take off the firstload time considerably *ie nil it :P )
+	mapSelectDialog();
 	//unitsync first load, NEEDS to be blocking
 	usync().ReloadUnitSyncLib();
 
@@ -186,12 +182,6 @@ bool SpringLobbyApp::OnInit()
 
 	if ( !m_customizer_modname.IsEmpty() ) {
 		if ( SLcustomizations().Init( m_customizer_modname ) ) {
-			if ( m_start_simple_interface ) {
-				SimpleFront* sp = new SimpleFront( 0 );
-				SetTopWindow( sp );
-				sp->Show();
-				return true;
-			}
 			ui().mw().SetIcon( SLcustomizations().GetAppIcon() );
 		}
 		else {
@@ -251,6 +241,7 @@ int SpringLobbyApp::OnExit()
   	sett().SaveSettings(); // to make sure that cache path gets saved before destroying unitsync
 
     SetEvtHandlerEnabled(false);
+	UiEvents::GetNotificationEventSender().Enable( false );
     DestroyGlobals();
 
     return 0;
@@ -297,7 +288,7 @@ void SpringLobbyApp::OnInitCmdLine(wxCmdLineParser& parser)
         #define STR
     #endif
 
-    wxCmdLineEntryDesc cmdLineDesc[] =
+    static const wxCmdLineEntryDesc cmdLineDesc[] =
     {
         { wxCMD_LINE_SWITCH, STR("h"), STR("help"), _("show this help message"), wxCMD_LINE_VAL_NONE, wxCMD_LINE_OPTION_HELP },
         { wxCMD_LINE_SWITCH, STR("nc"), STR("no-crash-handler"), _("don't use the crash handler (useful for debugging)"), wxCMD_LINE_VAL_NONE, wxCMD_LINE_PARAM_OPTIONAL },
@@ -306,10 +297,9 @@ void SpringLobbyApp::OnInitCmdLine(wxCmdLineParser& parser)
         { wxCMD_LINE_SWITCH, STR("gl"), STR("gui-logging"),  _("enables application log window"), wxCMD_LINE_VAL_NONE, wxCMD_LINE_PARAM_OPTIONAL },
         { wxCMD_LINE_OPTION, STR("f"), STR("config-file"),  _("override default choice for config-file"), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL | wxCMD_LINE_NEEDS_SEPARATOR },
         { wxCMD_LINE_OPTION, STR("l"), STR("log-verbosity"),  _("overrides default logging verbosity, can be:\n                                0: no log\n                                1: critical errors\n                                2: errors\n                                3: warnings (default)\n                                4: messages\n                                5: function trace"), wxCMD_LINE_VAL_NUMBER, wxCMD_LINE_PARAM_OPTIONAL },
-		{ wxCMD_LINE_OPTION, STR("c"), STR("customize"),  _("Load lobby customizations from game archive. Expects the long name."), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-		{ wxCMD_LINE_OPTION, STR("n"), STR("name"),  _("overrides default application name"), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
-        { wxCMD_LINE_SWITCH, STR("s"), STR("simple"),  _("Start with the simple interface."), wxCMD_LINE_VAL_NONE, wxCMD_LINE_PARAM_OPTIONAL },
-        { wxCMD_LINE_NONE }//while this throws warnings, it is mandatory according to http://docs.wxwidgets.org/stable/wx_wxcmdlineparser.html
+        { wxCMD_LINE_OPTION, STR("c"), STR("customize"),  _("load lobby customizations from game archive. Expects the long name."), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
+        { wxCMD_LINE_OPTION, STR("n"), STR("name"),  _("overrides default application name"), wxCMD_LINE_VAL_STRING, wxCMD_LINE_PARAM_OPTIONAL },
+        { wxCMD_LINE_NONE, NULL, NULL, NULL, wxCMD_LINE_VAL_NONE, wxCMD_LINE_PARAM_OPTIONAL } //this is mandatory according to http://docs.wxwidgets.org/stable/wx_wxcmdlineparser.html
     };
 
     parser.SetDesc( cmdLineDesc );
@@ -328,7 +318,6 @@ bool SpringLobbyApp::OnCmdLineParsed(wxCmdLineParser& parser)
         m_log_window_show = parser.Found(_T("gui-logging"));
 		m_log_file = parser.Found(_T("file-logging"), &m_log_file_path);
         m_crash_handle_disable = parser.Found(_T("no-crash-handler"));
-        m_start_simple_interface = parser.Found(_T("simple"));
 
         Settings::m_user_defined_config = parser.Found( _T("config-file"), &Settings::m_user_defined_config_path );
         if ( Settings::m_user_defined_config ) {
@@ -369,9 +358,10 @@ void SpringLobbyApp::CacheAndSettingsSetup()
 {
     SetSettingsStandAlone( false );
 
-    if ( sett().IsFirstRun() && !wxDirExists( wxStandardPaths::Get().GetUserDataDir() ) )
+	const wxString userConfigDir = GetConfigfileDir();
+	if ( sett().IsFirstRun() && !wxDirExists( userConfigDir ) )
     {
-        wxMkdir( wxStandardPaths::Get().GetUserDataDir() );
+		wxMkdir( userConfigDir );
     }
     if ( (sett().GetCacheVersion() < CACHE_VERSION) && !sett().IsFirstRun() )
     {
