@@ -141,6 +141,12 @@ MainWindow& Ui::mw()
     return *m_main_win;
 }
 
+const MainWindow& Ui::mw() const
+{
+	ASSERT_LOGIC( m_main_win != 0, _T("m_main_win = 0") );
+	return *m_main_win;
+}
+
 
 bool Ui::IsMainWindowCreated() const
 {
@@ -405,13 +411,13 @@ void Ui::DownloadFileWebsite( const wxString& name )
 //!
 //! @return true if OK button was pressed
 //! @note this does not return until the user pressed any of the buttons or closed the dialog.
-bool Ui::Ask( const wxString& heading, const wxString& question )
+bool Ui::Ask( const wxString& heading, const wxString& question ) const
 {
     int answer = customMessageBox( SL_MAIN_ICON, question, heading, wxYES_NO );
     return ( answer == wxYES );
 }
 
-
+//! cannot be const because parent window cannot be const
 bool Ui::AskPassword( const wxString& heading, const wxString& message, wxString& password )
 {
     wxPasswordEntryDialog pw_dlg( &mw(), message, heading, password );
@@ -431,7 +437,7 @@ bool Ui::AskText( const wxString& heading, const wxString& question, wxString& a
 }
 
 
-void Ui::ShowMessage( const wxString& heading, const wxString& message )
+void Ui::ShowMessage( const wxString& heading, const wxString& message ) const
 {
     if ( m_main_win == 0 ) return;
     serverMessageBox( SL_MAIN_ICON, message, heading, wxOK);
@@ -455,6 +461,7 @@ bool Ui::ExecuteSayCommand( const wxString& cmd )
     {
 		serverSelector().GetServer().GetMe().Status().away = true;
 		serverSelector().GetServer().GetMe().SendMyUserStatus();
+		mw().GetJoinTab().GetBattleRoomTab().UpdateMyInfo();
         return true;
     }
     else if ( cmd.BeforeFirst(' ').Lower() == _T("/back") )
@@ -463,6 +470,7 @@ bool Ui::ExecuteSayCommand( const wxString& cmd )
         {
 			serverSelector().GetServer().GetMe().Status().away = false;
 			serverSelector().GetServer().GetMe().SendMyUserStatus();
+			mw().GetJoinTab().GetBattleRoomTab().UpdateMyInfo();
             return true;
         }
     }
@@ -499,7 +507,7 @@ void Ui::ConsoleHelp( const wxString& topic )
     ChatPanel* panel = GetActiveChatPanel();
     if ( panel == 0 )
     {
-        ShowMessage( _("Help error"), _("Type /help in a chat box.") );
+		ShowMessage( _("Help error"), _("Type /help in a chat box. (A bug currently prevents this from working in battleroom") );
         return;
     }
     if ( topic == wxEmptyString )
@@ -509,7 +517,8 @@ void Ui::ConsoleHelp( const wxString& topic )
         panel->ClientMessage( _("Global commands:") );
         panel->ClientMessage( _("  \"/away\" - Sets your status to away.") );
         panel->ClientMessage( _("  \"/back\" - Resets your away status.") );
-        panel->ClientMessage( _("  \"/changepassword oldpassword newpassword\" - Changes the current active account's password.") );
+        panel->ClientMessage( _("  \"/changepassword2 newpassword\" - Changes the current active account's password, needs the old password saved in login box") );
+        panel->ClientMessage( _("  \"/changepassword oldpassword newpassword\" - Changes the current active account's password, password cannot contain spaces") );
         panel->ClientMessage( _("  \"/channels\" - Lists currently active channels.") );
         panel->ClientMessage( _("  \"/help [topic]\" - Put topic if you want to know more specific information about a command.") );
 		panel->ClientMessage( _("  \"/join channel [password]\" - Joins a channel.") );
@@ -570,7 +579,8 @@ void Ui::OnUpdate( int mselapsed )
             mw().ShowTab( sett().GetStartTab() );
         }
 #ifdef __WXMSW__
-        if ( sett().GetAutoUpdate() )
+		//don't ask for updates on first run, that's a bit much for a newbie
+		if ( sett().GetAutoUpdate() && !sett().IsFirstRun() )
             CheckForUpdates();
 #endif
     }
@@ -624,7 +634,7 @@ bool Ui::IsSpringCompatible()
       customMessageBoxNoModal(SL_MAIN_ICON,  _("Couldn't get your spring versions from any unitsync library.\n\nOnline play is currently disabled."), _("Spring error"), wxICON_EXCLAMATION|wxOK );
       return false;
     }
-    for ( std::map<wxString, wxString>::iterator itor = versionlist.begin(); itor != versionlist.end(); itor++ )
+	for ( std::map<wxString, wxString>::const_iterator itor = versionlist.begin(); itor != versionlist.end(); ++itor )
     {
       if ( itor->second == neededversion )
       {
@@ -639,7 +649,7 @@ bool Ui::IsSpringCompatible()
     }
     wxString message = wxString::Format( _("No compatible installed spring version has been found, this server requires version: %s\n"), neededversion.c_str() );
     message << _("Your current installed versions are:");
-    for ( std::map<wxString, wxString>::iterator itor = versionlist.begin(); itor != versionlist.end(); itor++ ) message << _T(" ") << itor->second;
+	for ( std::map<wxString, wxString>::const_iterator itor = versionlist.begin(); itor != versionlist.end(); ++itor ) message << _T(" ") << itor->second;
     message << _T("\n") << _("Online play is currently disabled.");
     customMessageBoxNoModal (SL_MAIN_ICON, message, _("Spring error"), wxICON_EXCLAMATION|wxOK );
     wxLogWarning ( _T("no spring version supported by the server found") );
@@ -675,10 +685,10 @@ void Ui::OnDisconnected( Server& server, bool wasonline )
 	wxString disconnect_msg = wxString::Format(_("disconnected from server: %s"), server.GetServerName().c_str() );
 	UiEvents::GetStatusEventSender( UiEvents::addStatusMessage ).SendEvent(
 			UiEvents::StatusData( disconnect_msg, 1 ) );
-	if ( sett().GetUseNotificationPopups() && !wxTheApp->IsActive() )
+	if ( !wxTheApp->IsActive() )
 	{
 		UiEvents::GetNotificationEventSender().SendEvent(
-				UiEvents::NotficationData( wxNullBitmap, disconnect_msg ) );
+				UiEvents::NotficationData( UiEvents::ServerConnection, disconnect_msg ) );
 	}
     if ( server.uidata.panel )
     {
@@ -718,7 +728,7 @@ void Ui::ConnectionFailurePrompt()
 		}
 		case wxID_NO: // switch to next server in the list
 		{
-			wxString m_last_used_backup_server = GetNextServer();
+			m_last_used_backup_server = GetNextServer();
 			wxString current_server = sett().GetDefaultServer();
 			sett().SetDefaultServer( m_last_used_backup_server );// temp set backup server as default
 			Connect();
@@ -764,14 +774,20 @@ static inline bool IsAutoJoinChannel( Channel& chan )
 //! @todo Check if a pannel allready exists for this channel
 void Ui::OnJoinedChannelSuccessful( Channel& chan )
 {
-    if ( m_main_win == 0 ) return;
-    wxLogDebugFunc( _T("") );
-
-    chan.uidata.panel = 0;
-
-    mw().OpenChannelChat( chan, !sett().GetAutoConnect() || !IsAutoJoinChannel( chan ) );
+	bool doFocus = !sett().GetAutoConnect() || !IsAutoJoinChannel( chan );
+	bool panel_exists = mw().GetChannelChatPanel( chan.GetName() ) != NULL;
+	OnJoinedChannelSuccessful( chan, !panel_exists && doFocus );
 }
 
+void Ui::OnJoinedChannelSuccessful( Channel& chan, bool focusTab )
+{
+	if ( m_main_win == 0 ) return;
+	wxLogDebugFunc( _T("") );
+
+	chan.uidata.panel = 0;
+
+	mw().OpenChannelChat( chan, focusTab );
+}
 
 //! @brief Called when something is said in a channel
 void Ui::OnChannelSaid( Channel& channel, User& user, const wxString& message )
@@ -989,6 +1005,16 @@ void Ui::OnUserSaid( User& user, const wxString& message, bool fromme )
     else user.uidata.panel->Said( user.GetNick(), message );
 }
 
+void Ui::OnUserSaidEx( User& user, const wxString& action, bool fromme )
+{
+	if ( m_main_win == 0 ) return;
+	if ( user.uidata.panel == 0 )
+	{
+		mw().OpenPrivateChat( user );
+	}
+	if ( fromme ) user.uidata.panel->DidAction ( serverSelector().GetServer().GetMe().GetNick(), action );
+	else user.uidata.panel->DidAction( user.GetNick(), action );
+}
 
 void Ui::OnBattleOpened( IBattle& battle )
 {
@@ -1065,7 +1091,7 @@ void Ui::OnUserJoinedBattle( IBattle& battle, User& user )
 }
 
 
-void Ui::OnUserLeftBattle( IBattle& battle, User& user )
+void Ui::OnUserLeftBattle( IBattle& battle, User& user, bool isbot )
 {
     if ( m_main_win == 0 ) return;
     user.SetSideiconIndex( -1 ); //just making sure he's not running around with some icon still set
@@ -1076,15 +1102,15 @@ void Ui::OnUserLeftBattle( IBattle& battle, User& user )
         if ( mw().GetJoinTab().GetBattleRoomTab().GetBattle() == &battle )
         {
             mw().GetJoinTab().GetBattleRoomTab().OnUserLeft( user );
-						OnBattleInfoUpdated( std::make_pair(&battle,wxString()) );
-			if ( &user == &serverSelector().GetServer().GetMe() )
+		 OnBattleInfoUpdated( std::make_pair(&battle,wxString()) );
+		if ( &user == &serverSelector().GetServer().GetMe() )
             {
                 mw().GetJoinTab().LeaveCurrentBattle();
             }
         }
     }
     catch (...) {}
-    if ( user.BattleStatus().IsBot() ) return;
+    if ( isbot ) return;
 	for ( int i = 0; i < serverSelector().GetServer().GetNumChannels(); i++ )
     {
 		Channel& chan = serverSelector().GetServer().GetChannel( i );
@@ -1244,12 +1270,44 @@ void Ui::OnRing( const wxString& from )
     if ( m_main_win == 0 ) return;
     m_main_win->RequestUserAttention();
 
-	if ( sett().GetUseNotificationPopups() && !wxTheApp->IsActive() )
+	if ( !wxTheApp->IsActive() )
 	{
 		UiEvents::GetNotificationEventSender().SendEvent(
-				UiEvents::NotficationData( wxNullBitmap, wxString::Format(_("%s:\nring!"),from.c_str()) ) );
+				UiEvents::NotficationData( UiEvents::ServerConnection, wxString::Format(_("%s:\nring!"),from.c_str()) ) );
 	}
 
+#ifndef NO_TORRENT_SYSTEM
+    if(serverSelector().GetServer().GetCurrentBattle()->GetMe().GetBattleStatus().sync == SYNC_UNSYNCED) {
+        wxString host_map_name = serverSelector().GetServer().GetCurrentBattle()->GetHostMapName();
+        if(! usync().MapExists(host_map_name)) {
+
+            map_infos info_map = torrent().CollectGuiInfos();
+            bool dling = false;
+
+            for(map_infos_iter iter = info_map.begin(); iter != info_map.end(); ++iter){
+                if(iter->first == wxString(_T("global")))
+                    continue;
+                else if(iter->first == host_map_name) {
+                    int eta = iter->second.eta;
+
+                    if(eta <= 0) {
+						serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(_("/me map is not available for automatic downloading."));
+                    } else {
+                        serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(wxString::Format(
+                                _("/me downloading map eta: %d s"), eta)
+                        );
+                    dling = true;
+                    }
+                }
+            }
+            if(! dling) { //XXX is it possible to get eta from web dl in sl?, anyone using it instead torrent system? //there is no direct from-web downloading in SL currently
+                serverSelector().GetServer().GetCurrentBattle()->ExecuteSayCommand(
+                        _("/me is not downloading map with SL torrent system"));
+            }
+        }
+    }
+#endif
+
 #ifndef DISABLE_SOUND
     if ( sett().GetChatPMSoundNotificationEnabled() )
         sound().ring();
@@ -1407,7 +1465,7 @@ void Ui::CheckForUpdates()
             else
             {//this will also happen if updater exe is not present so we don't really ne special check for existance of it
                 customMessageBox(SL_MAIN_ICON, _("Automatic update failed\n\nyou will be redirected to a web page with instructions and the download link will be opened in your browser.") + msg, _("Updater error.") );
-                OpenWebBrowser( _T("http://springlobby.info/wiki/springlobby/Install#Windows-Binary") );
+				OpenWebBrowser( _T("http://projects.springlobby.info/wiki/springlobby/Install#Windows-Binary") );
                 OpenWebBrowser( GetDownloadUrl( latestVersion ) );
 
             }
@@ -1421,3 +1479,4 @@ void Ui::CheckForUpdates()
         customMessageBoxNoModal(SL_MAIN_ICON, _("Your SpringLobby version is up to date.\n\n") + msg, _("Up to Date") );
     */
 }
+
